+++
title = "Quote blocks in numbered lists"
description = """
  Testing quote blocks in numbered lists, just because this came up on
  [Hugo Discourse](https://discourse.gohugo.io/t/put-a-blockquote-into-a-numbered-list/19339/1).
  """
tags = ["quotes", "lists"]
draft = false
+++

1.  List item 1

    Text before quote block.

    > Quote block in list item 1

    Text after quote block.
2.  List item 2

    Text before quote block.

    > Quote block in list item 2

    Text after quote block.
3.  List item 3

    Text before quote block.

    > Quote block in list item 3

    Text after quote block.
